@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict, Union
 
 import httpx
@@ -35,7 +36,7 @@ def _get_kwargs(
 
 def _build_response(*, response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=None,
