@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
 
 from ...client import Client
+from ...models.error import Error
 from ...models.instance_event import InstanceEvent
 from ...types import UNSET, Response, Unset
 
@@ -53,14 +55,22 @@ def _parse_response(
             response_200.append(response_200_item)
 
         return response_200
-    return None
+
+    # Nile has a known format for 40X errors, so regardless of the spec, lets return a Nile error
+    # Note that the type hint may or may not include Error type
+    if response.status_code >= 400 and response.status_code < 500:
+        return Error.from_dict(response.json())
+
+    # If it isn't 20X and isn't 40X, we don't know what to do.
+    # This is a hard-coded version of https://github.com/openapi-generators/openapi-python-client/pull/593
+    raise RuntimeError(f"Unexpected status code: {response.status_code}")
 
 
 def _build_response(
     *, response: httpx.Response
 ) -> Response[List[InstanceEvent]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=_parse_response(response=response),
@@ -77,6 +87,10 @@ def sync_detailed(
 ) -> Response[List[InstanceEvent]]:
     """Get instance events
 
+     Gets all events for the given entity type.
+    As access policies are enforced on events,
+    if the `before` instance fails access control, it will be omitted.
+
     Args:
         workspace (str):
         type (str):
@@ -113,6 +127,10 @@ def sync(
 ) -> Optional[List[InstanceEvent]]:
     """Get instance events
 
+     Gets all events for the given entity type.
+    As access policies are enforced on events,
+    if the `before` instance fails access control, it will be omitted.
+
     Args:
         workspace (str):
         type (str):
@@ -142,6 +160,10 @@ async def asyncio_detailed(
 ) -> Response[List[InstanceEvent]]:
     """Get instance events
 
+     Gets all events for the given entity type.
+    As access policies are enforced on events,
+    if the `before` instance fails access control, it will be omitted.
+
     Args:
         workspace (str):
         type (str):
@@ -176,6 +198,10 @@ async def asyncio(
 ) -> Optional[List[InstanceEvent]]:
     """Get instance events
 
+     Gets all events for the given entity type.
+    As access policies are enforced on events,
+    if the `before` instance fails access control, it will be omitted.
+
     Args:
         workspace (str):
         type (str):
