@@ -1,8 +1,10 @@
+from http import HTTPStatus
 from typing import Any, Dict, Optional
 
 import httpx
 
 from ...client import Client
+from ...models.error import Error
 from ...models.list_metric_definitions_response import (
     ListMetricDefinitionsResponse,
 )
@@ -38,14 +40,22 @@ def _parse_response(
         response_200 = ListMetricDefinitionsResponse.from_dict(response.json())
 
         return response_200
-    return None
+
+    # Nile has a known format for 40X errors, so regardless of the spec, lets return a Nile error
+    # Note that the type hint may or may not include Error type
+    if response.status_code >= 400 and response.status_code < 500:
+        return Error.from_dict(response.json())
+
+    # If it isn't 20X and isn't 40X, we don't know what to do.
+    # This is a hard-coded version of https://github.com/openapi-generators/openapi-python-client/pull/593
+    raise RuntimeError(f"Unexpected status code: {response.status_code}")
 
 
 def _build_response(
     *, response: httpx.Response
 ) -> Response[ListMetricDefinitionsResponse]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=_parse_response(response=response),
